@@ -4,12 +4,6 @@ This plugin broadcasts a message to all your joined rooms.
 .. note:: With great power comes great responsability.
           Use with moderation.
 
-Installation
-------------
-You only have to load the plugin.::
-
-    /load amsg
-
 Command
 -------
 
@@ -18,10 +12,12 @@ Command
     /amsg
         **Usage:** ``/amsg <message>``
 
+        Broadcast a message.
+
 
 """
-from plugin import BasePlugin
-from tabs import MucTab
+from poezio.plugin import BasePlugin
+from poezio.tabs import MucTab
 
 class Plugin(BasePlugin):
     def init(self):
