@@ -1,18 +1,8 @@
 """
-Shout
-
-Installation
-------------
-
-You only have to load the plugin:
-
-.. code-block:: none
-
-    /load capslock
-
-
+Once loaded, everything you will send will be IN CAPITAL LETTERS.
 """
-from plugin import BasePlugin
+from poezio.plugin import BasePlugin
+from poezio import xhtml
 
 class Plugin(BasePlugin):
     def init(self):
@@ -21,4 +11,4 @@ class Plugin(BasePlugin):
         self.api.add_event_handler('private_say', self.caps)
 
     def caps(self, msg, tab):
-        msg['body'] = msg['body'].upper()
+        msg['body'] = xhtml.clean_text(msg['body']).upper()
