@@ -2,13 +2,6 @@
 This plugin uses figlet to transform every message into a big ascii-art
 message.
 
-Installation
-------------
-You only have to load the plugin (and have :file:`figlet` installed, of course).
-::
-
-    /load figlet
-
 
 Usage
 -----
@@ -18,7 +11,7 @@ Say something in a Chat tab.
 .. note:: Can create fun things when used with :ref:`The rainbow plugin <rainbow-plugin>`.
 
 """
-from plugin import BasePlugin
+from poezio.plugin import BasePlugin
 import subprocess
 
 class Plugin(BasePlugin):
