@@ -1,14 +1,7 @@
 """
 This plugin colors each character of a message with a random color.
 
-Installation
-------------
-
-You only have to load the plugin.
-
-.. code-block:: none
-
-    /load rainbow
+.. note:: As ticket `#3273`_ puts it, the final output is closer to vomit than a rainbow.
 
 Usage
 -----
@@ -20,9 +13,11 @@ Usage
         Say something in a Chat tab.
 
 .. note:: Can create fun things when used with :ref:`The figlet plugin <figlet-plugin>`.
+
+.. _#3273: https://dev.louiz.org/issues/3273
 """
-from plugin import BasePlugin
-import xhtml
+from poezio.plugin import BasePlugin
+from poezio import xhtml
 import random
 
 possible_colors = list(range(256))
