@@ -1,11 +1,5 @@
 """
-This plugin makes you have a random nick when joining a MUC.
-
-Installation
-------------
-You only have to load the plugin.::
-
-    /load random_nick
+This plugin makes you have a random nick when joining a chatroom.
 
 Usage
 -----
@@ -17,8 +11,7 @@ automatically be changed to something random, for example: ::
 
 """
 
-from plugin import BasePlugin
-from tabs import MucTab
+from poezio.plugin import BasePlugin
 from random import choice
 
 class Plugin(BasePlugin):
@@ -37,6 +30,6 @@ c = ["b", "c", "d", "f", "g", "h", "j", "k", "m", "l", "n", "p", "r", "s", "t",
 
 def gen_nick(size):
     res = ''
-    for i in range(size):
+    for _ in range(size):
         res += '%s%s' % (choice(c), choice(s))
     return res
