@@ -1,16 +1,9 @@
 """
-Insert a space between each character, in messages that you send.
-
-Installation
-------------
-
-You only have to load the plugin:
-
-.. code-block:: none
-        /load spaces
-
+Insert a space between each character, in messages that you send, making
+them horrible to read.
 """
-from plugin import BasePlugin
+from poezio.plugin import BasePlugin
+from poezio import xhtml
 
 class Plugin(BasePlugin):
     def init(self):
@@ -19,4 +12,4 @@ class Plugin(BasePlugin):
         self.api.add_event_handler('private_say', self.add_spaces)
 
     def add_spaces(self, msg, tab):
-        msg['body'] = " ".join(x for x in msg['body'])
+        msg['body'] = " ".join(x for x in xhtml.clean_text(msg['body']))
