@@ -1,14 +1,6 @@
 """
 This plugin adds several aliases, to shorten status changes.
 
-Installation
-------------
-You only have to load the plugin.
-
-.. code-block:: none
-
-    /load status
-
 Aliases
 -------
 
@@ -33,7 +25,7 @@ Aliases
         Set your status to ``xa``
 
 """
-from plugin import BasePlugin
+from poezio.plugin import BasePlugin
 
 class Plugin(BasePlugin):
     """
